@@ -94,6 +94,8 @@ class ContractRegistry(Registry):
 
 
     def set(self, contract_address, sender_address, identifier_string, address):
+        if len(identifier_string) > 32:
+            raise ValueError('String too long')
         enc = ABIContractEncoder()
         enc.method('set')
         enc.typ(ABIContractType.BYTES32)
